#
# spec file for package k3b
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_with    lame
%bcond_with    mad
%define         k3b_codec_subpkg 0

Name:           k3b
Version:        2.0.3
Release:        9.2
Summary:        CD/DVD/Blu-ray Burning Application for KDE
License:        GPL-2.0+
Group:          Productivity/Multimedia/CD/Record
Url:            http://www.k3b.org/
Source:         http://download.kde.org/stable/%{name}/%{name}-%{version}a.tar.xz
# PATCH-FIX-OPENSUSE initial-preference.diff llunak@novell.com -- Make the default handler for .iso files instead of Ark
Patch0:         initial-preference.diff
# PATCH-FIX-OPENSUSE building-docs-once-is-enough.patch  -- Fix build when CMP002 policy is set to NEW
Patch1:         building-docs-once-is-enough.patch
# PATCH-FIX-UPSTREAM fix-dvd-transcoding.patch kde#350403 -- Fix transcoding of DVD titles
Patch2:         fix-dvd-transcoding.patch
# PATCH-FIX-UPSTREAM k3b-2.0.3-gcc6.patch dimstar@opensuse.org -- Fix build with GCC 6
Patch3:         k3b-2.0.3-gcc6.patch
# PATCH-FIX arch linux k3b-ffmpeg3.patch - fix build with ffmpeg 3x abi
Patch4:         k3b-ffmpeg3.patch

BuildRequires:  fdupes
BuildRequires:  flac-devel
BuildRequires:  libdvdread-devel
BuildRequires:  libkcddb4-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmusicbrainz-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libvorbis-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(taglib)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
%endif
%if %{with lame}
%define k3b_codec_subpkg 1
BuildRequires:  libmp3lame-devel
Requires:       lame
%endif
%if %{with mad}
%define k3b_codec_subpkg 1
BuildRequires:  pkgconfig(mad)
%endif
Requires:       %{_bindir}/cdrdao
Requires:       %{_bindir}/cdrecord
Requires:       %{_bindir}/mkisofs
Requires:       %{_bindir}/readcd
Requires:       dvd+rw-tools
Requires(post):  hicolor-icon-theme
Requires(postun):  hicolor-icon-theme
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Recommends:     %{_bindir}/normalize
Recommends:     %{_bindir}/sox
Recommends:     %{_bindir}/transcode
Recommends:     %{name}-lang = %{version}
Recommends:     vcdimager
Provides:       kde4-k3b = 4.2.2.svn951754
Obsoletes:      kde4-k3b < 4.2.2.svn951754
%if 0%{?k3b_codec_subpkg}
# External documentation and 1-click install references this package name
Provides:       k3b-codecs = %{version}-%{release}
Obsoletes:      k3b-codecs < %{version}-%{release}
%else
Obsoletes:      k3b-codecs
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?kde4_runtime_requires}

%description
Featuring a simple, yet powerful graphical interface, k3b provides various
options for burning a CD, DVD, or BD (Blu-ray disc). Various types of optical
projects are supported including (but not limited to) audio and data, video
projects for DVD and VCD, as well as multi-session and mixed-mode discs. k3b
also has the ability to erase re-writeable media and can perform more
complicated tasks such as audiovisual encoding and decoding.

%package devel
Summary:        Development files for k3b
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contain files needed for development with k3b.

%lang_package

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
CXXFLAGS="%{optflags} -fno-strict-aliasing"
%cmake_kde4 -d build -- -DK3B_ENABLE_HAL_SUPPORT=OFF
%make_jobs

%install
%kde4_makeinstall -C build

%suse_update_desktop_file -r k3b Qt KDE AudioVideo DiscBurning

# symlink solid actions into place known to Plasma 5, remove once k3b is KF5-based
mkdir -p %{buildroot}%{_datadir}/solid/actions
pushd %{buildroot}%{_kde4_appsdir}/solid/actions/
for i in k3b_*.desktop; do
ln -s %{_kde4_appsdir}/solid/actions/$i %{buildroot}%{_datadir}/solid/actions/
done
popd

%fdupes -s %{buildroot}

%find_lang k3b k3b.lang
%find_lang k3bsetup k3b.lang
%find_lang libk3b k3b.lang
%find_lang libk3bdevice k3b.lang
%find_lang kio_videodvd k3b.lang

%kde_post_install

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc COPYING* ChangeLog FAQ PERMISSIONS README
%{_kde4_bindir}/k3b
%{_kde4_bindir}/k3bsetup
%{_kde4_modulesdir}/k3b*.so
%{_kde4_modulesdir}/kcm_k3b*.so
%{_kde4_modulesdir}/kio_videodvd.so
%{_kde4_libexecdir}/k3bsetuphelper
%{_kde4_libdir}/libk3bdevice.so.*
%{_kde4_libdir}/libk3blib.so.*
%{_kde4_applicationsdir}/k3b.desktop
%doc %{_kde4_htmldir}/en/k3b/
%{_kde4_iconsdir}/hicolor/*/apps/k3b.*
%{_kde4_appsdir}/k3b/
%{_kde4_appsdir}/konqsidebartng/virtual_folders/services/videodvd.desktop
%dir %{_kde4_appsdir}/solid
%dir %{_kde4_appsdir}/solid/actions
%{_kde4_appsdir}/solid/actions/k3b_*.desktop
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%{_datadir}/solid/actions/k3b_*.desktop
%{_kde4_servicesdir}/ServiceMenus/k3b_*.desktop
%{_kde4_servicesdir}/k3b*.desktop
%{_kde4_servicesdir}/kcm_k3b*.desktop
%{_kde4_servicesdir}/videodvd.protocol
%{_kde4_servicetypesdir}/k3bplugin.desktop
%{_kde4_datadir}/mime/packages/x-k3b.xml
%config %{_sysconfdir}/dbus-1/system.d/org.kde.kcontrol.k3bsetup.conf
%{_kde4_datadir}/dbus-1/system-services/org.kde.kcontrol.k3bsetup.service
%{_kde4_datadir}/polkit-1/actions/org.kde.kcontrol.k3bsetup.policy

%files devel
%defattr(-,root,root,-)
%{_kde4_includedir}/k3b*.h
%{_kde4_libdir}/libk3bdevice.so
%{_kde4_libdir}/libk3blib.so

%files lang -f k3b.lang
%defattr(-,root,root,-)
%exclude %{_kde4_htmldir}/en/k3b/

%changelog
* Mon Jan  2 2017 olaf@aepfle.de
- Add Provided/Obsolete k3b-codecs if built with mad/lame support
  External documentation and 1-click install references this
  package name
* Wed Nov 30 2016 wbauer@tmo.at
- Obsolete k3b-codecs, the additional codecs are part of the main
  package now
* Tue Nov 29 2016 olaf@aepfle.de
- Restore conditionals for lame and libmad
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
- Remove unused ffmpeg pkgs
* Sat Jun 25 2016 davejplater@gmail.com
- Add k3b-ffmpeg3.patch from arch linux to fix build against
  ffmpeg 3x
* Wed May 25 2016 dimstar@opensuse.org
- Add k3b-2.0.3-gcc6.patch: Fix build with GCC 6. Patch copied from
  Gentoo.
* Mon Jan  4 2016 tittiatcoke@gmail.com
- Use the internal ffmpeg package to build.
  This would prevent to swap k3b with the one from packman to have
  mp3 support
* Thu Dec 24 2015 alarrosa@suse.com
- Added Requires(post/un) hicolor-icon-theme since it's needed by
  %%icon_theme_cache_post/un
* Wed Dec 23 2015 alarrosa@suse.com
- Updated initial-preference.diff so it applies without any offset
* Fri Nov  6 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Use buildorig syntax instead of with/without conditionals
- Remove icons magic that is not needed anymore
* Fri Oct 30 2015 wbauer@tmo.at
- Add fix-dvd-transcoding.patch: Fix transcoding of DVD titles
  (kde#350403)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Added building-docs-once-is-enough.patch: Fix build when CMP002
  policy is set to NEW
* Fri Jun  5 2015 wbauer@tmo.at
- fix solid actions symlinks
* Sun May 17 2015 hrvoje.senjan@gmail.com
- Symlink solid actions into place known to Plasma 5
* Tue Mar 31 2015 wbauer@tmo.at
- Remove unnecessary Requires: cdparanoia-devel, this was added
  as a workaround for a bug in the 2.0.80git version (kde#328769),
  but this is long fixed and never was present in the stable 2.0
  branch anyway
* Tue Nov 11 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Drop ImageMagick BuildRequires together with adjusting png's as
  they are fixed upstream
- Drop version checks for ancient openSUSE versions
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Update to 2.0.3:
  * Fixed crash in MetaItemModel on submodel item removal
  * Fixed Solid predicates for AudioCd and VideoDvd media.
    kde#265819
  * Set error status when CDDB query fails.
  * Prefer growisofs to wodim for DVD/BluRay burning.
  * Fixed improper track number in CDDB track edit window title.
    kde#276681
  * Fixed crash on detecting writing speeds. kde#272427
  * Fix problem with HL-DT-ST BH10LS30. kde#268307
  * Fixed compilation with new FFMPEG. kde#274817 kde#300731
  * Allow using CD-R90 and CD-R99 media to full capacity.
    kde#276002
  * Refactor the FreeBSD SCSI/CAM interface.
  * Fix crash on dvd ripping
  * fix sox detection with sox >= 14.4.0. kde#301544
  * Support more media types. kde#261652
  * Fix file system detection. kde#325616 kde#262607
  * Surround output filename for transcode with double quotes.
    kde#326097
  * Fix FILE name and type detection for cue sheet images.
    kde#337201
  * Rip audio tracks in ascending numerical order.
    kde#319678
  * Upstream patches from NetBSD.
  * Make paranoia lib detection better.
  * Don't preview if called process failed. kde#268680
  * Fix Crash while remove songs in "Mixed mode CD proyect".
    kde#323117
  * Use QElapsedTimer to calculate remaining time.
    kde#330239 kde#315463
  * Fix crash in lsof wrapper. kde#340515
- Drop patches merged upstream:
  k3b-prefer-growisofs-to-wodim-for-DVD-burning.patch,
  k3b-fixed-crash-on-detecting-writing-speeds.patch,
  k3b-fixed-solid-predicates.patch,
  k3b-2.0.2-ffmpeg011.patch,
  k3b-short-trackinfo.patch,
  k3b-increase-tolerance.patch,
  add_mimetypes_bnc661777.diff,
  k3b-fixed-improper-track-number-in-CDDB-track-edit-window-title.patch,
  k3b-set-error-status-when-CDDB-query-fails.patch and
  k3b-dont-count-used-capacity-twice.patch
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Use kde4-macros for filelists, k3b uses kdelibs4 buildsystem
* Sun Jun 22 2014 ctrippe@opensuse.org
- Add Requires: cdparanoia-devel to make copying of a CD work
  (kde#328769)
* Tue Feb 19 2013 dmitry_r@opensuse.org
- Replace recommended package dependencies with file dependencies
* Mon Dec 17 2012 hrvoje.senjan@gmail.com
- Add various bugfixes from upstream 2.0 branch
  * k3b-dont-count-used-capacity-twice.patch (kde#276002)
  * k3b-fixed-crash-on-detecting-writing-speeds.patch (kde#272427)
  * k3b-fixed-improper-track-number-in-CDDB-track-edit-window-title.patch (kde#276681)
  * k3b-fixed-solid-predicates.patch (kde#265819)
  * k3b-increase-tolerance.patch (kde#276002)
  * k3b-prefer-growisofs-to-wodim-for-DVD-burning.patch
  * k3b-set-error-status-when-CDDB-query-fails.patch
* Wed Jul 25 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11. Took from Packman.
* Sun Apr 15 2012 dmueller@suse.com
- update buildrequires (taglib->libtag)
* Wed Aug 31 2011 idonmez@suse.com
- Add k3b-short-trackinfo.patch: Too short track info dataLen
  returned at least on HL-DT-ST BH10LS30 , bko #268307
* Sun Aug 14 2011 reddwarf@opensuse.org
- Add k3b-2.0.2-ffmpeg08.patch to allow it to compile against the
  new ffmpeg versions.
* Wed Apr 27 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Cleanup in Buildrequires: entries.
  * Added /usr/bin/readcd in Requires:.
  * Recommend normalize, sox, transcode and vcdimager packages.
  * Fixed rpmlint warning for Provides/Obsoletes of kde4-k3b.
  * Updates in Url:, Summary: and %%description.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Changed k3b-devel Group: to "Development/Libraries/C and C++".
  * Compile the package with "-fno-strict-aliasing".
  * Added "AudioVideo" to the Categories entry of k3b.desktop file.
  * Remove some more locales for openSUSE < 11.4.
  * Moved english help files in the main package.
  * Updates in %%files section (also removed support for openSUSE < 11.2).
  * Minor other updates.
- Fixed some rpmlint warnings.
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Fix type in spec-file
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Fri Jan 28 2011 embar@super.lt
- Since using option -DK3B_ENABLE_HAL_SUPPORT=OFF, HAL is not required
* Sun Jan 16 2011 tittiatcoke@gmail.com
- Update to 2.0.2:
  * Changes:
  - Added K3B_ENABLE_HAL_SUPPORT option to the build configuration.
    It allows to disable any direct calls to HAL (bko#253388)
  - Using Oxygen sounds for events (bko#242395)
  * Bugfixes:
  - Crash on start when checking device capabilities (bko#246822)
  - Search paths on "Programs" options are not saved (bko#248648)
  - Crash on generation of DVD previews in DVD ripping list
    (bko#249941, bko#253639)
  - Crash on closing dialog after succesful audio CD ripping
    (bko#241630)
  - Crash on device detection (bko#249371)
  - Crash when showing settings window (bko#238819)
  - Fixed playlist sort order (bko#249395)
  - Show K3b also in "System" category in KDE launch menus
    (bko#250749)
  - Crash when multiple instances start at the same time
    (bko#253794)
  - Crash after track splitting (bko#261188)
  - Inline editing of tracks in CD ripping view no longer works
    (bko#250600)
* Thu Dec 30 2010 ctrippe@gmx.net
- Add a few mimetypes to the desktop file for better integration in
  GNOME (bnc#661777)
* Sun Nov 28 2010 jslaby@suse.de
- Device detection crash fix
* Fri Oct 22 2010 abrouwers@gmail.com
- Fix crash entering settings dialog with qt47 (upstream
  http://websvn.kde.org/?revision=1186323&view=revision)
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Tue Aug 17 2010 beineri@opensuse.org
- update to 2.0.1: several bugfixes
* Fri Aug 13 2010 vuntz@opensuse.org
- Drop unneeded libnjb-devel BuildRequires.
* Tue Jun 29 2010 tittiatcoke@gmail.com
- Update to final version of 2.0.0:
  * fixed german translation, no code change
* Fri Jun 18 2010 llunak@novell.com
- HAL is required for K3B to work (bnc#613898)
- make the default handler for .iso files instead of Ark
* Thu Jun 17 2010 wstephenson@novell.com
- Update to 1.93 (2.0rc4)
  Changes:
  * Moved K3b Handbook to http://userbase.kde.org/K3b
  * Improved checking/unchecking items using Space key. Previously to do that the current item had to be in first column.
  Bugfixes:
  * Cannot choose between cdrecord when both cdrecord and wodim are installed (bko#239861)
  * Crash when files have been removed right before burning the project (bko#240398)
  * Crash when moving a file into a directory with Shift key pressed (bko#239075)
  * Invalid parameter to cdrecord for non-integer burning speed (bko#240310)
  * Crash when burning CD Audio project with tracks from another CD (bko#240450)
  * Crash when turning off the drive (bko#235743)
  * Crash when importing previous session (bko#235734)
  * Various crashes during manipulation of eMovix project view
  * Hang before verification (bko#156684)
  * Crash when "Waiting for medium" dialog is closed (bko#232148)
* Wed May 26 2010 llunak@novell.com
- fix build for <= 11.2
* Tue May 25 2010 wstephenson@novell.com
- update to 1.92 (2.0rc3)
  + Bugfixes:
  * In some cases medium doesn’t get accepted for multisession burning (bko#230742)
  * Data files in VCD ripping view are not listed
  * Show “Modify Permissions” button in System Problem Dialog only when it makes sense (bko#230706)
  * Crash after “Cancel” was clicked while adding audio files to AudioCD project (bko#231348)
  * Error window at the start when a place on the left pane is not accessible (bko#230194)
  * Incorrect minimum size of welcome widget (bko#231939)
  * Hangs while ripping AudioCD with data tracks (bko#231174)
  * Crash when auto-removing non-existing files from a project before the burning (bko#236005)
  * Empty Blu-ray medium not detected properly (bko#236069)
  * eMovix project cannot be burned (bko#236823)
  * M3U playlist not read properly (bko#237654)
  * K3b overwrites iso ignoring user choice on dvd copy with option “only create image” checked (bko#185251)
  * Compilation fails with FFmpeg version SVN-r23001 (bko#236036)
  * Crash when waiting for reload the medium
* Wed Mar 17 2010 coolo@novell.com
- fix file list
* Wed Mar 10 2010 tittiatcoke@gmail.com
- update to 1.91 (2.0rc2)
  + New:
  * K3bSetup ported to KAuth framework
  + Bugfixes:
  * Crash on start of Audio Ripping Dialog (bko#226595)
  * Incorrect ordering of files added to Audio Project (bko#224649)
  * Too wide Image burn Dialog when file path was long (bko#225735)
  * Crash when creating image files for AudioCD project (bko#219500)
  * Crash when manipulating VCD project items (bko#227855)
  * Mixed-up metadata in files created with external encoder (bko#227927)
  * Cannot edit time values in "Split Audio Track" and "Edit Audio Track"
    dialog (bko#229042)
  * Empty Bly-ray mediam not detected properly (bko#227339, bko#229039)
  * Crash during splitting/editing audio tracks
  * Entry fields doesn't work in burn window when "Only Create Image"
    option is checked (bko#220970)
  * Layout issues in settings window (bko#227733)
* Tue Feb  9 2010 tittiatcoke@gmail.com
- update to 1.70 (2.0 Beta 1)
  Changes:
  * Added Blu-ray support
  * Added "Options" button to file browser toolbar with view options menu
    (e.g. "Show Hidden Files") (bko#196992)
  * Image and project files can be opened directly from K3b file browser
  * Using Oxygen icons (many thanks for Oxygen Team!)
  Bugfixes:
  * Fixed visual glitch when panes are in "locked" state.
    Patch by Craig Drummond <craig@kde.org>
  * Fixed hang up when "Create Image" option is checked (bko#217301)
  * "Hide main window while writing" option is working again
  * "Show OSD progress" option is working again
  * Improved message when ISO with incorrect size is detected (bko#216812)
  * Improved consistency: K3b now uses system-wide
    Positive/Neutral/Negative colors where possible instead of
    hard-coded green/yellow/red
  * Fixed incorrect default value "4gb." in "Custom Size" dialog (bko#215539)
  * Fixed usability issues with project size menu:
    "Custom..." and "From Medium..." menu entries are non-checkable now (bko#215539)
  * Show correct message at the end of CD-RW erasing (bko#207972)
  * Fixed issue with too small configuration dialog for external encoder (bko#218613)
  * Track number is now stored in ripped MP3 files when using lame (bko#218614)
  * "Defaults" button in encoder configuration dialogs are working now
  * Fixed usability problems of audio project list
  * Fixed linking error on Windows
  * Fixed crash during verification process (bko#219962)
  * Fixed crash in external encoder plug-in
  * Brought back SOX encoder configuration dialog
  * Fixed checking free space in temporary folder
  * Fixed videodvd:/ KIO slave
  * Fixed hang-up for mixed projects after reloading medium for verification
  * Converting audio tracks from audio project is working again
  * Fixed burning bootable discs
  * Custom widgets are now properly rendered for Right-to-Left languages
  * Progress bar in image writing dialog is shown again
  * Fixed crash while analysing invalid medium (bko#223362)
  * Acquire lock also on storage interface. This prevents HAL from
    polling medium during burning which might disrupt burning process.
  * Fixed bug in external programs detection (bko#221638)
  * Improved usability: don't show popups when clicking on DVD, VCD or
    audio discs. Added appriopriate actions on toolbars instead.
  * Fixed crash while analysing invalid medium (bko#195436)
* Sat Nov 28 2009 tittiatcoke@gmail.com
- update to 1.69 Alpha 4: Even more bugfixes
* Sat Oct 17 2009 beineri@opensuse.org
- update to 1.68 Alpha 3: many bugfixes
- updated translations from SVN
* Sun Oct  4 2009 beineri@opensuse.org
- updated translations from SVN
* Tue Aug 11 2009 beineri@opensuse.org
- update to r1009369, add documentation & translations (bnc#529600)
* Thu Jul 30 2009 beineri@opensuse.org
- apply trunk diff (r1004480) when building on 11.2
* Thu Jul 23 2009 beineri@opensuse.org
- apply trunk diff (r1001450) when building on 11.2
* Wed May 27 2009 beineri@opensuse.org
- update to 1.66 Alpha 2: many bugfixes
* Sun May  3 2009 cmorve69@yahoo.es
- Add support for Musepack/MPC
- Disable K3BSetup
* Thu Apr 23 2009 beineri@opensuse.org
- rename to k3b, update to 1.65.0 Alpha
* Sat Mar 21 2009 beineri@opensuse.org
- update to 4.2.1.svn942189
* Wed Feb 25 2009 stbinner@suse.de
- update to 4.2.0.svn931376
* Wed Feb 18 2009 stbinner@suse.de
- update to 4.2.0.svn927728
* Fri Jan 23 2009 stbinner@suse.de
- update to 4.1.4.svn915827
* Wed Jan  7 2009 stbinner@suse.de
- update to 4.1.4.svn907132
* Tue Dec 16 2008 stbinner@suse.de
- update to 4.1.3.svn897517
* Sat Nov 22 2008 stbinner@suse.de
- update to 4.1.3.svn887510
* Fri Nov  7 2008 stbinner@suse.de
- update to 4.1.3.svn881374
* Sat Sep 13 2008 stbinner@suse.de
- update to 4.1.1.svn860449
* Fri Aug 22 2008 stbinner@suse.de
- update to 4.1.0.svn851044
* Fri Jul 25 2008 stbinner@suse.de
- update to 4.1.0.svn837567
* Wed Jul 16 2008 stbinner@suse.de
- update to 4.0.98.svn833153
* Fri Jun 27 2008 dmueller@suse.de
- update to 4.0.84.svn825098
* Tue Jun  3 2008 dmueller@suse.de
- update to 4.0.81.svn816194
* Thu May 15 2008 dmueller@suse.de
- update to 4.0.74.svn808129
* Wed May  7 2008 dmueller@suse.de
- update to 4.0.73.svn805196
* Thu Apr 24 2008 dmueller@suse.de
- update to 4.0.71.svn800684
* Fri Apr 18 2008 dmueller@suse.de
- update to 4.0.69.svn798537
* Wed Apr  2 2008 dmueller@suse.de
- update to 4.0.68.svn792936
* Thu Feb 14 2008 dmueller@suse.de
- update to 4.0.62.svn775117
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.0.svn742626
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.0.svn731749
